@@ -1,6 +1,6 @@
 /* Eye of Gnome - Main Window
  *
- * Copyright (C) 2000-2006 The Free Software Foundation
+ * Copyright (C) 2000-2008 The Free Software Foundation
  *
  * Author: Lucas Rocha <lucasr@gnome.org>
  *
@@ -30,11 +30,6 @@
 
 #include "eog-list-store.h"
 #include "eog-image.h"
-/*
-#include "eog-thumb-nav.h"
-#include "eog-thumb-view.h"
-#include "eog-statusbar.h"
-*/
 
 #include <glib.h>
 #include <glib-object.h>
@@ -55,6 +50,13 @@ typedef struct _EogWindowPrivate EogWindowPrivate;
 
 #define EOG_WINDOW_ERROR           (eog_window_error_quark ())
 
+typedef enum {
+	EOG_WINDOW_MODE_UNKNOWN,
+	EOG_WINDOW_MODE_NORMAL,
+	EOG_WINDOW_MODE_FULLSCREEN,
+	EOG_WINDOW_MODE_SLIDESHOW
+} EogWindowMode;
+
 //TODO
 typedef enum {
 	EOG_WINDOW_ERROR_CONTROL_NOT_FOUND,
@@ -88,10 +90,17 @@ GType         eog_window_get_type  	(void) G_GNUC_CONST;
 
 GtkWidget    *eog_window_new		(EogStartupFlags  flags);
 
+EogWindowMode eog_window_get_mode       (EogWindow       *window);
+
+void          eog_window_set_mode       (EogWindow       *window,
+					 EogWindowMode    mode);
+
 GtkUIManager *eog_window_get_ui_manager (EogWindow       *window);
 
 EogListStore *eog_window_get_store      (EogWindow       *window);
 
+GtkWidget    *eog_window_get_view       (EogWindow       *window);
+
 GtkWidget    *eog_window_get_sidebar    (EogWindow       *window);
 
 GtkWidget    *eog_window_get_thumb_view (EogWindow       *window);
@@ -102,11 +111,12 @@ GtkWidget    *eog_window_get_statusbar  (EogWindow       *window);
 
 EogImage     *eog_window_get_image      (EogWindow       *window);
 
-void          eog_window_open_uri_list	(EogWindow       *window, 
-					 GSList          *uri_list);
+void          eog_window_open_file_list	(EogWindow       *window, 
+					 GSList          *file_list);
 
 gboolean      eog_window_is_empty 	(EogWindow       *window);
 
+void          eog_window_reload_image (EogWindow *window);
 G_END_DECLS
 
 #endif
